@@ -2,6 +2,10 @@ from munch import Munch
 
 Shared = Munch()
 
+Shared.fileSystem = None
+
+Shared.vepCheckWaitTime = 5
+
 Shared.CurrentStageForLogging = None
 Shared.CurrentFunctionForLogging = list()
 
